@@ -19,34 +19,13 @@ from .utils import NamespacedClient, query_params, SKIP_IN_PATH, _make_path
 
 
 class AutoscalingClient(NamespacedClient):
-    @query_params()
-    def get_autoscaling_decision(self, params=None, headers=None):
-        """
-        Gets the current autoscaling decision based on the configured autoscaling
-        policy, indicating whether or not autoscaling is needed.
-
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/autoscaling-get-autoscaling-decision.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
-        """
-        return self.transport.perform_request(
-            "GET", "/_autoscaling/decision", params=params, headers=headers
-        )
-
     @query_params()
     def delete_autoscaling_policy(self, name, params=None, headers=None):
         """
-        Deletes an autoscaling policy.
+        Deletes an autoscaling policy. Designed for indirect use by ECE/ESS and ECK.
+        Direct use is not supported.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/autoscaling-delete-autoscaling-policy.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/autoscaling-delete-autoscaling-policy.html>`_
 
         :arg name: the name of the autoscaling policy
         """
@@ -63,14 +42,10 @@ class AutoscalingClient(NamespacedClient):
     @query_params()
     def get_autoscaling_policy(self, name, params=None, headers=None):
         """
-        Retrieves an autoscaling policy.
+        Retrieves an autoscaling policy. Designed for indirect use by ECE/ESS and ECK.
+        Direct use is not supported.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/autoscaling-get-autoscaling-policy.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/autoscaling-get-autoscaling-policy.html>`_
 
         :arg name: the name of the autoscaling policy
         """
@@ -87,14 +62,10 @@ class AutoscalingClient(NamespacedClient):
     @query_params()
     def put_autoscaling_policy(self, name, body, params=None, headers=None):
         """
-        Creates a new autoscaling policy.
+        Creates a new autoscaling policy. Designed for indirect use by ECE/ESS and ECK.
+        Direct use is not supported.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/autoscaling-put-autoscaling-policy.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/autoscaling-put-autoscaling-policy.html>`_
 
         :arg name: the name of the autoscaling policy
         :arg body: the specification of the autoscaling policy
@@ -110,3 +81,16 @@ class AutoscalingClient(NamespacedClient):
             headers=headers,
             body=body,
         )
+
+    @query_params()
+    def get_autoscaling_capacity(self, params=None, headers=None):
+        """
+        Gets the current autoscaling capacity based on the configured autoscaling
+        policy. Designed for indirect use by ECE/ESS and ECK. Direct use is not
+        supported.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/autoscaling-get-autoscaling-capacity.html>`_
+        """
+        return self.transport.perform_request(
+            "GET", "/_autoscaling/capacity", params=params, headers=headers
+        )
