@@ -25,7 +25,7 @@ class IndicesClient(NamespacedClient):
         Performs the analysis process on a text and return the tokens breakdown of the
         text.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-analyze.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-analyze.html>`_
 
         :arg body: Define analyzer/tokenizer parameters and the text on
             which the analysis should be performed
@@ -44,7 +44,7 @@ class IndicesClient(NamespacedClient):
         """
         Performs the refresh operation in one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-refresh.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-refresh.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -72,7 +72,7 @@ class IndicesClient(NamespacedClient):
         """
         Performs the flush operation on one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-flush.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-flush.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string for all indices
@@ -105,7 +105,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates an index with optional settings and mappings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-create-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-create-index.html>`_
 
         :arg index: The name of the index
         :arg body: The configuration for the index (`settings` and
@@ -129,7 +129,7 @@ class IndicesClient(NamespacedClient):
         """
         Clones an index
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-clone-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-clone-index.html>`_
 
         :arg index: The name of the source index to clone
         :arg target: The name of the target index to clone into
@@ -166,7 +166,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-get-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-get-index.html>`_
 
         :arg index: A comma-separated list of index names
         :arg allow_no_indices: Ignore if a wildcard expression resolves
@@ -205,7 +205,7 @@ class IndicesClient(NamespacedClient):
         """
         Opens an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-open-close.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-open-close.html>`_
 
         :arg index: A comma separated list of indices to open
         :arg allow_no_indices: Whether to ignore if a wildcard indices
@@ -240,7 +240,7 @@ class IndicesClient(NamespacedClient):
         """
         Closes an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-open-close.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-open-close.html>`_
 
         :arg index: A comma separated list of indices to close
         :arg allow_no_indices: Whether to ignore if a wildcard indices
@@ -274,7 +274,7 @@ class IndicesClient(NamespacedClient):
         """
         Deletes an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-delete-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-delete-index.html>`_
 
         :arg index: A comma-separated list of indices to delete; use
             `_all` or `*` string to delete all indices
@@ -307,7 +307,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about whether a particular index exists.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-exists.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-exists.html>`_
 
         :arg index: A comma-separated list of index names
         :arg allow_no_indices: Ignore if a wildcard expression resolves
@@ -337,7 +337,7 @@ class IndicesClient(NamespacedClient):
         Returns information about whether a particular document type exists.
         (DEPRECATED)
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-types-exists.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-types-exists.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` to
             check the types across all indices
@@ -377,7 +377,7 @@ class IndicesClient(NamespacedClient):
         """
         Updates the index mappings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-put-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-put-mapping.html>`_
 
         :arg body: The mapping definition
         :arg index: A comma-separated list of index names the mapping
@@ -425,7 +425,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns mappings for one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-get-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-get-mapping.html>`_
 
         :arg index: A comma-separated list of index names
         :arg doc_type: A comma-separated list of document types
@@ -464,7 +464,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns mapping for one or more fields.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-get-field-mapping.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-get-field-mapping.html>`_
 
         :arg fields: A comma-separated list of fields
         :arg index: A comma-separated list of index names
@@ -499,7 +499,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates or updates an alias.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
 
         :arg index: A comma-separated list of index names the alias
             should point to (supports wildcards); use `_all` to perform the
@@ -527,7 +527,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about whether a particular alias exists.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
 
         :arg name: A comma-separated list of alias names to return
         :arg index: A comma-separated list of index names to filter
@@ -555,7 +555,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns an alias.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
 
         :arg index: A comma-separated list of index names to filter
             aliases
@@ -580,7 +580,7 @@ class IndicesClient(NamespacedClient):
         """
         Updates index aliases.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
 
         :arg body: The definition of `actions` to perform
         :arg master_timeout: Specify timeout for connection to master
@@ -598,7 +598,7 @@ class IndicesClient(NamespacedClient):
         """
         Deletes an alias.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-aliases.html>`_
 
         :arg index: A comma-separated list of index names (supports
             wildcards); use `_all` for all indices
@@ -620,7 +620,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates or updates an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg body: The template definition
@@ -650,7 +650,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about whether a particular index template exists.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg name: The comma separated names of the index templates
         :arg flat_settings: Return settings in flat format (default:
@@ -672,7 +672,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg name: The comma separated names of the index templates
         :arg flat_settings: Return settings in flat format (default:
@@ -693,7 +693,7 @@ class IndicesClient(NamespacedClient):
         """
         Deletes an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg master_timeout: Specify timeout for connection to master
@@ -719,7 +719,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns settings for one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-get-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-get-settings.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -757,7 +757,7 @@ class IndicesClient(NamespacedClient):
         """
         Updates the index settings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-update-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-update-settings.html>`_
 
         :arg body: The index settings to be updated
         :arg index: A comma-separated list of index names; use `_all` or
@@ -805,7 +805,7 @@ class IndicesClient(NamespacedClient):
         """
         Provides statistics on operations happening in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-stats.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -849,7 +849,7 @@ class IndicesClient(NamespacedClient):
         """
         Provides low-level information about segments in a Lucene index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-segments.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-segments.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -887,7 +887,7 @@ class IndicesClient(NamespacedClient):
         """
         Allows a user to validate a potentially expensive query without executing it.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/search-validate.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/search-validate.html>`_
 
         :arg body: The query definition specified with the Query DSL
         :arg index: A comma-separated list of index names to restrict
@@ -941,7 +941,7 @@ class IndicesClient(NamespacedClient):
         """
         Clears all or specific caches for one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-clearcache.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-clearcache.html>`_
 
         :arg index: A comma-separated list of index name to limit the
             operation
@@ -968,7 +968,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about ongoing index shard recoveries.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-recovery.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-recovery.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -990,9 +990,9 @@ class IndicesClient(NamespacedClient):
     )
     def upgrade(self, index=None, params=None, headers=None):
         """
-        The _upgrade API is no longer useful and will be removed.
+        DEPRECATED Upgrades to the current version of Lucene.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-upgrade.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-upgrade.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -1016,9 +1016,9 @@ class IndicesClient(NamespacedClient):
     @query_params("allow_no_indices", "expand_wildcards", "ignore_unavailable")
     def get_upgrade(self, index=None, params=None, headers=None):
         """
-        The _upgrade API is no longer useful and will be removed.
+        DEPRECATED Returns a progress status of current upgrade.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-upgrade.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-upgrade.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -1041,7 +1041,7 @@ class IndicesClient(NamespacedClient):
         Performs a synced flush operation on one or more indices. Synced flush is
         deprecated and will be removed in 8.0. Use flush instead
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-synced-flush-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-synced-flush-api.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string for all indices
@@ -1068,7 +1068,7 @@ class IndicesClient(NamespacedClient):
         """
         Provides store information for shard copies of indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-shards-stores.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-shards-stores.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -1100,7 +1100,7 @@ class IndicesClient(NamespacedClient):
         """
         Performs the force merge operation on one or more indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-forcemerge.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-forcemerge.html>`_
 
         :arg index: A comma-separated list of index names; use `_all` or
             empty string to perform the operation on all indices
@@ -1130,7 +1130,7 @@ class IndicesClient(NamespacedClient):
         """
         Allow to shrink an existing index into a new index with fewer primary shards.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-shrink-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-shrink-index.html>`_
 
         :arg index: The name of the source index to shrink
         :arg target: The name of the target index to shrink into
@@ -1163,7 +1163,7 @@ class IndicesClient(NamespacedClient):
         Allows you to split an existing index into a new index with more primary
         shards.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-split-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-split-index.html>`_
 
         :arg index: The name of the source index to split
         :arg target: The name of the target index to split into
@@ -1200,7 +1200,7 @@ class IndicesClient(NamespacedClient):
         Updates an alias to point to a new index when the existing index is considered
         to be too large or too old.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-rollover-index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-rollover-index.html>`_
 
         :arg alias: The name of the alias to rollover
         :arg body: The conditions that needs to be met for executing
@@ -1241,7 +1241,7 @@ class IndicesClient(NamespacedClient):
         Freezes an index. A frozen index has almost no overhead on the cluster (except
         for maintaining its metadata in memory) and is read-only.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/freeze-index-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/freeze-index-api.html>`_
 
         :arg index: The name of the index to freeze
         :arg allow_no_indices: Whether to ignore if a wildcard indices
@@ -1277,7 +1277,7 @@ class IndicesClient(NamespacedClient):
         Unfreezes an index. When a frozen index is unfrozen, the index goes through the
         normal recovery process and becomes writeable again.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/unfreeze-index-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/unfreeze-index-api.html>`_
 
         :arg index: The name of the index to unfreeze
         :arg allow_no_indices: Whether to ignore if a wildcard indices
@@ -1305,7 +1305,7 @@ class IndicesClient(NamespacedClient):
         """
         Reloads an index's search analyzers and their resources.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-reload-analyzers.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-reload-analyzers.html>`_
 
         :arg index: A comma-separated list of index names to reload
             analyzers for
@@ -1333,7 +1333,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates a data stream
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
 
         :arg name: The name of the data stream
         """
@@ -1344,15 +1344,18 @@ class IndicesClient(NamespacedClient):
             "PUT", _make_path("_data_stream", name), params=params, headers=headers
         )
 
-    @query_params()
+    @query_params("expand_wildcards")
     def delete_data_stream(self, name, params=None, headers=None):
         """
         Deletes a data stream.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
 
         :arg name: A comma-separated list of data streams to delete; use
             `*` to delete all data streams
+        :arg expand_wildcards: Whether wildcard expressions should get
+            expanded to open or closed indices (default: open)  Valid choices: open,
+            closed, hidden, none, all  Default: open
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'name'.")
@@ -1366,12 +1369,7 @@ class IndicesClient(NamespacedClient):
         """
         Deletes an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg master_timeout: Specify timeout for connection to master
@@ -1392,12 +1390,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about whether a particular index template exists.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg flat_settings: Return settings in flat format (default:
@@ -1419,12 +1412,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg name: The comma separated names of the index templates
         :arg flat_settings: Return settings in flat format (default:
@@ -1443,12 +1431,7 @@ class IndicesClient(NamespacedClient):
         """
         Creates or updates an index template.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg name: The name of the template
         :arg body: The template definition
@@ -1476,12 +1459,7 @@ class IndicesClient(NamespacedClient):
         Simulate matching the given index name against the index templates in the
         system
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg name: The name of the index (it must be a concrete index
             name)
@@ -1505,15 +1483,18 @@ class IndicesClient(NamespacedClient):
             body=body,
         )
 
-    @query_params()
+    @query_params("expand_wildcards")
     def get_data_stream(self, name=None, params=None, headers=None):
         """
         Returns data streams.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
 
         :arg name: A comma-separated list of data streams to get; use
             `*` to get all data streams
+        :arg expand_wildcards: Whether wildcard expressions should get
+            expanded to open or closed indices (default: open)  Valid choices: open,
+            closed, hidden, none, all  Default: open
         """
         return self.transport.perform_request(
             "GET", _make_path("_data_stream", name), params=params, headers=headers
@@ -1524,12 +1505,7 @@ class IndicesClient(NamespacedClient):
         """
         Simulate resolving the given template name or body
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-templates.html>`_
-
-        .. warning::
-
-            This API is **experimental** so may include breaking changes
-            or be removed in a future version
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-templates.html>`_
 
         :arg body: New index template definition to be simulated, if no
             index template name is specified
@@ -1554,7 +1530,7 @@ class IndicesClient(NamespacedClient):
         """
         Returns information about any matching indices, aliases, and data streams
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/indices-resolve-index-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/indices-resolve-index-api.html>`_
 
         .. warning::
 
@@ -1585,7 +1561,7 @@ class IndicesClient(NamespacedClient):
         """
         Adds a block to an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/index-modules-blocks.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/index-modules-blocks.html>`_
 
         :arg index: A comma separated list of indices to add a block to
         :arg block: The block to add (one of read, write, read_only or
@@ -1614,7 +1590,7 @@ class IndicesClient(NamespacedClient):
         """
         Provides statistics on operations happening in a data stream.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/data-streams.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
 
         :arg name: A comma-separated list of data stream names; use
             `_all` or empty string to perform the operation on all data streams
@@ -1625,3 +1601,42 @@ class IndicesClient(NamespacedClient):
             params=params,
             headers=headers,
         )
+
+    @query_params()
+    def promote_data_stream(self, name, params=None, headers=None):
+        """
+        Promotes a data stream from a replicated data stream managed by CCR to a
+        regular data stream
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
+
+        :arg name: The name of the data stream
+        """
+        if name in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for a required argument 'name'.")
+
+        return self.transport.perform_request(
+            "POST",
+            _make_path("_data_stream", "_promote", name),
+            params=params,
+            headers=headers,
+        )
+
+    @query_params()
+    def migrate_to_data_stream(self, name, params=None, headers=None):
+        """
+        Migrates an alias to a data stream
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.11/data-streams.html>`_
+
+        :arg name: The name of the alias to migrate
+        """
+        if name in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for a required argument 'name'.")
+
+        return self.transport.perform_request(
+            "POST",
+            _make_path("_data_stream", "_migrate", name),
+            params=params,
+            headers=headers,
+        )
