@@ -1,15 +1,39 @@
+#  Licensed to Elasticsearch B.V. under one or more contributor
+#  license agreements. See the NOTICE file distributed with
+#  this work for additional information regarding copyright
+#  ownership. Elasticsearch B.V. licenses this file to you under
+#  the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+# 	http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
+
 import logging
 import binascii
 import gzip
 import io
+import re
 from platform import python_version
+import warnings
 
 try:
     import simplejson as json
 except ImportError:
     import json
 
-from ..exceptions import TransportError, ImproperlyConfigured, HTTP_EXCEPTIONS
+from ..exceptions import (
+    TransportError,
+    ImproperlyConfigured,
+    ElasticsearchWarning,
+    HTTP_EXCEPTIONS,
+)
 from .. import __versionstr__
 
 logger = logging.getLogger("elasticsearch")
@@ -21,6 +45,8 @@ tracer = logging.getLogger("elasticsearch.trace")
 if not _tracer_already_configured:
     tracer.propagate = False
 
+_WARNING_RE = re.compile(r"\"([^\"]*)\"")
+
 
 class Connection(object):
     """
@@ -37,8 +63,12 @@ class Connection(object):
     :arg timeout: default timeout in seconds (float, default: 10)
     :arg http_compress: Use gzip compression
     :arg cloud_id: The Cloud ID from ElasticCloud. Convenient way to connect to cloud instances.
+    :arg opaque_id: Send this value in the 'X-Opaque-Id' HTTP header
+        For tracing all requests made by this transport.
     """
 
+    HTTP_CLIENT_META = None
+
     def __init__(
         self,
         host="localhost",
@@ -49,6 +79,9 @@ class Connection(object):
         headers=None,
         http_compress=None,
         cloud_id=None,
+        api_key=None,
+        opaque_id=None,
+        meta_header=True,
         **kwargs
     ):
 
@@ -85,10 +118,15 @@ class Connection(object):
         headers = headers or {}
         for key in headers:
             self.headers[key.lower()] = headers[key]
+        if opaque_id:
+            self.headers["x-opaque-id"] = opaque_id
 
         self.headers.setdefault("content-type", "application/json")
         self.headers.setdefault("user-agent", self._get_default_user_agent())
 
+        if api_key is not None:
+            self.headers["authorization"] = self._get_api_key_header_val(api_key)
+
         if http_compress:
             self.headers["accept-encoding"] = "gzip,deflate"
 
@@ -99,9 +137,13 @@ class Connection(object):
         self.use_ssl = use_ssl
         self.http_compress = http_compress or False
 
+        self.scheme = scheme
         self.hostname = host
         self.port = port
-        self.host = "%s://%s" % (scheme, host)
+        if ":" in host:  # IPv6
+            self.host = "%s://[%s]" % (scheme, host)
+        else:
+            self.host = "%s://%s" % (scheme, host)
         if self.port is not None:
             self.host += ":%s" % self.port
         if url_prefix:
@@ -109,15 +151,54 @@ class Connection(object):
         self.url_prefix = url_prefix
         self.timeout = timeout
 
+        if not isinstance(meta_header, bool):
+            raise TypeError("meta_header must be of type bool")
+        self.meta_header = meta_header
+
     def __repr__(self):
         return "<%s: %s>" % (self.__class__.__name__, self.host)
 
+    def __eq__(self, other):
+        if not isinstance(other, Connection):
+            raise TypeError("Unsupported equality check for %s and %s" % (self, other))
+        return self.__hash__() == other.__hash__()
+
+    def __hash__(self):
+        return id(self)
+
     def _gzip_compress(self, body):
         buf = io.BytesIO()
         with gzip.GzipFile(fileobj=buf, mode="wb") as f:
             f.write(body)
         return buf.getvalue()
 
+    def _raise_warnings(self, warning_headers):
+        """If 'headers' contains a 'Warning' header raise
+        the warnings to be seen by the user. Takes an iterable
+        of string values from any number of 'Warning' headers.
+        """
+        if not warning_headers:
+            return
+
+        # Grab only the message from each header, the rest is discarded.
+        # Format is: '(number) Elasticsearch-(version)-(instance) "(message)"'
+        warning_messages = []
+        for header in warning_headers:
+            # Because 'Requests' does it's own folding of multiple HTTP headers
+            # into one header delimited by commas (totally standard compliant, just
+            # annoying for cases like this) we need to expect there may be
+            # more than one message per 'Warning' header.
+            matches = _WARNING_RE.findall(header)
+            if matches:
+                warning_messages.extend(matches)
+            else:
+                # Don't want to throw away any warnings, even if they
+                # don't follow the format we have now. Use the whole header.
+                warning_messages.append(header)
+
+        for message in warning_messages:
+            warnings.warn(message, category=ElasticsearchWarning)
+
     def _pretty_json(self, data):
         # pretty JSON in tracer curl logs
         try:
@@ -152,6 +233,18 @@ class Connection(object):
                 self._pretty_json(response).replace("\n", "\n#") if response else "",
             )
 
+    def perform_request(
+        self,
+        method,
+        url,
+        params=None,
+        body=None,
+        timeout=None,
+        ignore=(),
+        headers=None,
+    ):
+        raise NotImplementedError()
+
     def log_request_success(
         self, method, full_url, path, body, status_code, response, duration
     ):
@@ -232,3 +325,14 @@ class Connection(object):
 
     def _get_default_user_agent(self):
         return "elasticsearch-py/%s (Python %s)" % (__versionstr__, python_version())
+
+    def _get_api_key_header_val(self, api_key):
+        """
+        Check the type of the passed api_key and return the correct header value
+        for the `API Key authentication <https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-create-api-key.html>`
+        :arg api_key, either a tuple or a base64 encoded string
+        """
+        if isinstance(api_key, (tuple, list)):
+            s = "{0}:{1}".format(api_key[0], api_key[1]).encode("utf-8")
+            return "ApiKey " + binascii.b2a_base64(s).rstrip(b"\r\n").decode("utf-8")
+        return "ApiKey " + api_key
