@@ -1,8 +1,25 @@
+#  Licensed to Elasticsearch B.V. under one or more contributor
+#  license agreements. See the NOTICE file distributed with
+#  this work for additional information regarding copyright
+#  ownership. Elasticsearch B.V. licenses this file to you under
+#  the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+# 	http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing,
+#  software distributed under the License is distributed on an
+#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+#  KIND, either express or implied.  See the License for the
+#  specific language governing permissions and limitations
+#  under the License.
+
 import time
 import ssl
-import urllib3
-from urllib3.exceptions import ReadTimeoutError, SSLError as UrllibSSLError
-from urllib3.util.retry import Retry
+import urllib3  # type: ignore
+from urllib3.exceptions import ReadTimeoutError, SSLError as UrllibSSLError  # type: ignore
+from urllib3.util.retry import Retry  # type: ignore
 import warnings
 
 from .base import Connection
@@ -13,11 +30,13 @@ from ..exceptions import (
     SSLError,
 )
 from ..compat import urlencode
+from ..utils import _client_meta_version
 
-# sentinel value for `verify_certs`.
-# This is used to detect if a user is passing in a value for `verify_certs`
-# so we can raise a warning if using SSL kwargs AND SSLContext.
-VERIFY_CERTS_DEFAULT = None
+# sentinel value for `verify_certs` and `ssl_show_warn`.
+# This is used to detect if a user is passing in a value
+# for SSL kwargs if also using an SSLContext.
+VERIFY_CERTS_DEFAULT = object()
+SSL_SHOW_WARN_DEFAULT = object()
 
 CA_CERTS = None
 
@@ -53,6 +72,7 @@ class Urllib3HttpConnection(Connection):
         string or a tuple
     :arg use_ssl: use ssl for the connection if `True`
     :arg verify_certs: whether to verify SSL certificates
+    :arg ssl_show_warn: show warning when verify certs is disabled
     :arg ca_certs: optional path to CA bundle.
         See https://urllib3.readthedocs.io/en/latest/security.html#using-certifi-with-urllib3
         for instructions how to get default set
@@ -72,8 +92,13 @@ class Urllib3HttpConnection(Connection):
     :arg http_compress: Use gzip compression
     :arg cloud_id: The Cloud ID from ElasticCloud. Convenient way to connect to cloud instances.
         Other host connection params will be ignored.
+    :arg api_key: optional API Key authentication as either base64 encoded string or a tuple.
+    :arg opaque_id: Send this value in the 'X-Opaque-Id' HTTP header
+        For tracing all requests made by this transport.
     """
 
+    HTTP_CLIENT_META = ("ur", _client_meta_version(urllib3.__version__))
+
     def __init__(
         self,
         host="localhost",
@@ -81,6 +106,7 @@ class Urllib3HttpConnection(Connection):
         http_auth=None,
         use_ssl=False,
         verify_certs=VERIFY_CERTS_DEFAULT,
+        ssl_show_warn=SSL_SHOW_WARN_DEFAULT,
         ca_certs=None,
         client_cert=None,
         client_key=None,
@@ -92,6 +118,8 @@ class Urllib3HttpConnection(Connection):
         ssl_context=None,
         http_compress=None,
         cloud_id=None,
+        api_key=None,
+        opaque_id=None,
         **kwargs
     ):
         # Initialize headers before calling super().__init__().
@@ -104,6 +132,8 @@ class Urllib3HttpConnection(Connection):
             headers=headers,
             http_compress=http_compress,
             cloud_id=cloud_id,
+            api_key=api_key,
+            opaque_id=opaque_id,
             **kwargs
         )
         if http_auth is not None:
@@ -117,6 +147,7 @@ class Urllib3HttpConnection(Connection):
         # if providing an SSL context, raise error if any other SSL related flag is used
         if ssl_context and (
             (verify_certs is not VERIFY_CERTS_DEFAULT)
+            or (ssl_show_warn is not SSL_SHOW_WARN_DEFAULT)
             or ca_certs
             or client_cert
             or client_key
@@ -146,9 +177,12 @@ class Urllib3HttpConnection(Connection):
                 }
             )
 
-            # If `verify_certs` is sentinal value, default `verify_certs` to `True`
+            # Convert all sentinel values to their actual default
+            # values if not using an SSLContext.
             if verify_certs is VERIFY_CERTS_DEFAULT:
                 verify_certs = True
+            if ssl_show_warn is SSL_SHOW_WARN_DEFAULT:
+                ssl_show_warn = True
 
             ca_certs = CA_CERTS if ca_certs is None else ca_certs
             if verify_certs:
@@ -168,11 +202,14 @@ class Urllib3HttpConnection(Connection):
                     }
                 )
             else:
-                warnings.warn(
-                    "Connecting to %s using SSL with verify_certs=False is insecure."
-                    % self.host
-                )
                 kw["cert_reqs"] = "CERT_NONE"
+                if ssl_show_warn:
+                    warnings.warn(
+                        "Connecting to %s using SSL with verify_certs=False is insecure."
+                        % self.host
+                    )
+                if not ssl_show_warn:
+                    urllib3.disable_warnings()
 
         self.pool = pool_class(
             self.hostname, port=self.port, timeout=self.timeout, maxsize=maxsize, **kw
@@ -184,6 +221,7 @@ class Urllib3HttpConnection(Connection):
         url = self.url_prefix + url
         if params:
             url = "%s?%s" % (url, urlencode(params))
+
         full_url = self.host + url
 
         start = time.time()
@@ -212,7 +250,7 @@ class Urllib3HttpConnection(Connection):
                 method, url, body, retries=Retry(False), headers=request_headers, **kw
             )
             duration = time.time() - start
-            raw_data = response.data.decode("utf-8")
+            raw_data = response.data.decode("utf-8", "surrogatepass")
         except Exception as e:
             self.log_request_fail(
                 method, full_url, url, orig_body, time.time() - start, exception=e
@@ -223,6 +261,10 @@ class Urllib3HttpConnection(Connection):
                 raise ConnectionTimeout("TIMEOUT", str(e), e)
             raise ConnectionError("N/A", str(e), e)
 
+        # raise warnings if any from the 'Warnings' header.
+        warning_headers = response.headers.get_all("warning", ())
+        self._raise_warnings(warning_headers)
+
         # raise errors based on http status codes, let the client handle those if needed
         if not (200 <= response.status < 300) and response.status not in ignore:
             self.log_request_fail(
